Installation
============

Dependencies
------------

Required:

-  `numpy <http://www.numpy.org>`__
-  `scipy <https://www.scipy.org>`__

Optional (only loaded when methods are called that rely on these packages):

-  `rtree <http://toblerity.org/rtree/>`__
-  `nvector <https://github.com/pbrod/Nvector>`__
-  `gpxpy <https://github.com/tkrajina/gpxpy>`__
-  `pyproj <https://jswhit.github.io/pyproj/>`__
-  `pykalman <https://pykalman.github.io>`__
-  `matplotlib <http://matplotlib.org>`__
-  `smopy <https://github.com/rossant/smopy>`__


Using pip
---------

If you want to install the latest released version using pip:

::

    $ pip install leuvenmapmatching

If you want to install the latest non-released version (add ``@develop``) for the
latest development version:

::

    $ pip install git+https://github.com/wannesm/leuvenmapmatching


From source
-----------

The library can also be compiled and/or installed directly from source.

* Download the source from https://github.com/wannesm/leuvenmapmatching
* To compile and install in your site-package directory: ``python3 setup.py install``

